AshScylla.Search.Analyzer.StopWords (AshScylla v1.6.1)

Copy Markdown View Source

Stop words filter for the search pipeline.

Removes common English words that carry little semantic value and would otherwise create enormous partitions in the inverted index.

The stop word list is based on the standard English stop words used by Lucene and similar search engines.

Summary

Functions

Removes stop words from a list of terms.

Checks if a term is a stop word.

Returns the full set of stop words.

Functions

filter(terms)

@spec filter([String.t()]) :: [String.t()]

Removes stop words from a list of terms.

stop_word?(term)

@spec stop_word?(String.t()) :: boolean()

Checks if a term is a stop word.

stop_words()

@spec stop_words() :: MapSet.t()

Returns the full set of stop words.